import{h as f,N as n,q as u,a as v,L as h,g,b as A}from"./DaFfdZrU.js";const k=Symbol("is custom element"),l=Symbol("is html");function p(r){if(f){var e=!1,s=()=>{if(!e){if(e=!0,r.hasAttribute("value")){var t=r.value;i(r,"value",null),r.value=t}if(r.hasAttribute("checked")){var a=r.checked;i(r,"checked",null),r.checked=a}}};r.__on_r=s,u(s),v()}}function y(r,e){var s=o(r);s.value===(s.value=e??void 0)||r.value===e&&(e!==0||r.nodeName!=="PROGRESS")||(r.value=e??"")}function E(r,e){var s=o(r);s.checked!==(s.checked=e??void 0)&&(r.checked=e)}function i(r,e,s,t){var a=o(r);f&&(a[e]=r.getAttribute(e),e==="src"||e==="srcset"||e==="href"&&r.nodeName==="LINK")||a[e]!==(a[e]=s)&&(e==="loading"&&(r[h]=s),s==null?r.removeAttribute(e):typeof s!="string"&&N(r).includes(e)?r[e]=s:r.setAttribute(e,s))}function o(r){return r.__attributes??={[k]:r.nodeName.includes("-"),[l]:r.namespaceURI===n}}var _=new Map;function N(r){var e=r.getAttribute("is")||r.nodeName,s=_.get(e);if(s)return s;_.set(e,s=[]);for(var t,a=r,d=Element.prototype;d!==a;){t=A(a);for(var c in t)t[c].set&&s.push(c);a=g(a)}return s}export{y as a,E as b,p as r,i as s};
