import{e as v,Q as c,R as o,T,U as p,V as N,h as f,i,W as w,F as x,X as y,K as C,Y as F}from"./DaFfdZrU.js";function h(r){var n=document.createElement("template");return n.innerHTML=r.replaceAll("<!>","<!---->"),n.content}function t(r,n){var e=c;e.nodes===null&&(e.nodes={start:r,end:n,a:null,t:null})}function D(r,n){var e=(n&p)!==0,l=(n&N)!==0,s,_=!r.startsWith("<!>");return()=>{if(f)return t(i,null),i;s===void 0&&(s=h(_?r:"<!>"+r),e||(s=o(s)));var a=l||T?document.importNode(s,!0):s.cloneNode(!0);if(e){var m=o(a),d=a.lastChild;t(m,d)}else t(a,a);return a}}function A(r,n,e="svg"){var l=!r.startsWith("<!>"),s=(n&p)!==0,_=`<${e}>${l?r:"<!>"+r}</${e}>`,a;return()=>{if(f)return t(i,null),i;if(!a){var m=h(_),d=o(m);if(s)for(a=document.createDocumentFragment();o(d);)a.appendChild(o(d));else a=o(d)}var u=a.cloneNode(!0);if(s){var E=o(u),g=u.lastChild;t(E,g)}else t(u,u);return u}}function L(r,n){return A(r,n,"svg")}function O(r=""){if(!f){var n=v(r+"");return t(n,n),n}var e=i;return e.nodeType!==y?(e.before(e=v()),C(e)):F(e),t(e,e),e}function P(){if(f)return t(i,null),i;var r=document.createDocumentFragment(),n=document.createComment(""),e=v();return r.append(n,e),t(n,e),r}function b(r,n){if(f){var e=c;((e.f&w)===0||e.nodes.end===null)&&(e.nodes.end=i),x();return}r!==null&&r.before(n)}const M="5";typeof window<"u"&&((window.__svelte??={}).v??=new Set).add(M);export{b as a,t as b,P as c,h as d,L as e,D as f,O as t};
