import{a as h,f as w}from"../chunks/BsXlBeBh.js";import{v as _,l as j,w as n,x,y,z as u,A as a,B as o,C as i,D as p}from"../chunks/DaFfdZrU.js";import{d as k,s as b}from"../chunks/CtdJfFSR.js";import{s as A}from"../chunks/Bp7fEV_w.js";const z=()=>{const e=A;return{page:{subscribe:e.page.subscribe},navigating:{subscribe:e.navigating.subscribe},updated:e.updated}},B={subscribe(e){return z().page.subscribe(e)}};var C=w('<div class="error-page svelte-1j96wlh"><div class="error-icon-wrap svelte-1j96wlh"><div class="error-icon-glow svelte-1j96wlh"></div> <div class="error-icon svelte-1j96wlh">&times;</div></div> <div class="error-code svelte-1j96wlh"> </div> <div class="error-message svelte-1j96wlh"> </div> <button class="retry-btn svelte-1j96wlh">Retry</button></div>');function q(e,c){_(c,!0);let l=u(0),v=u("");j(()=>B.subscribe(d=>{n(l,d.status,!0),n(v,d.error?.message??"An unexpected error occurred",!0)}));var s=C(),r=a(o(s),2),g=o(r,!0);i(r);var t=a(r,2),m=o(t,!0);i(t);var f=a(t,2);f.__click=()=>location.reload(),i(s),x(()=>{b(g,p(l)),b(m,p(v))}),h(e,s),y()}k(["click"]);export{q as component};
